==> CustomChat-1.0.3.tar.gz: CustomChat-1.0.3/README.md <==
# CustomChat

CustomChat is an easily customizable AI chatbot powered by Jimbot AI. Whether you're running it on an online compiler or locally, CustomChat empowers you to tailor it to your specific needs.

## Installation

To install CustomChat, follow these steps:

1. Download the zip file from the latest release and unzip it.

2. Navigate to the CustomChat directory:
   <pre><code>cd CustomChat</code></pre>
   
3. Run the code:
   <pre><code>python3 main.py</code></pre>

   This will start CustomChat and you can begin customizing it for your needs.

### Requirements

CustomChat requires the following Python libraries:
- `bs4` (Beautiful Soup): For web scraping capabilities.
- `requests` For making HTTP requests.

These are already in the "Dependencies" folder.

## Customization

Tailoring CustomChat to your requirements is a breeze. You can personalize the chatbot's name and incorporate keywords to suit your preferences. Simply access the "Name" file and modify it with your desired name. Additionally, to integrate your own keywords, initiate CustomChat and input "edit" to follow the prompts.

## Restrictions

CustomChat offers flexibility in managing permissions. Should you wish to impose restrictions, such as prohibiting users from executing commands, you can effortlessly adjust settings in the configuration file. By toggling values from True to False, you can define the level of access granted to users.

## Capabilities

CustomChat boasts an array of functionalities to enhance user experience:

- **Website and File Access:** Configure CustomChat to open websites and files as per your requirements.
- **Command Execution:** Enable CustomChat to execute commands, providing seamless interaction.
- **Keyword-based Responses:** Customize CustomChat to deliver specific responses based on designated keywords.

Moreover, CustomChat's capabilities extend to:

- **Web Scraping:** Leveraging web scraping capabilities, CustomChat can retrieve information from various online sources.
- **General Knowledge:** Accessing Google through web scraping, CustomChat can provide answers to general inquiries.
- **Command Line Integration:** With access to the command line, CustomChat enables users to execute commands effortlessly by typing "run" followed by the desired command.

For further information about the AI powering CustomChat, visit [Jimbot AI](https://jb.mrpi314.com/ai).

Enhance your chatbot experience with CustomChat's versatility and adaptability.

==> CustomChat-1.0.5.tar.gz: CustomChat-1.0.5/README.md <==
# CustomChat

CustomChat is an easily customizable AI chatbot powered by Jimbot AI. Whether you're running it on an online compiler or locally, CustomChat empowers you to tailor it to your specific needs.

## Installation

To install CustomChat, follow these steps:

1. Download the package with pip:
   <pre><code>pip install CustomChat</code></pre>
   
3. Run the code with python:
   <pre><code>import CustomChat
   CustomChat.run()</code></pre>

   This will start CustomChat and you can begin customizing it for your needs.

### Requirements

CustomChat requires the following Python libraries:
- `bs4` (Beautiful Soup): For web scraping capabilities.
- `requests` For making HTTP requests.

These are already in the "Dependencies" folder.

## Customization

Tailoring CustomChat to your requirements is a breeze. You can personalize the chatbot's name and incorporate keywords to suit your preferences. Simply access the "Name" file and modify it with your desired name. Additionally, to integrate your own keywords, initiate CustomChat and input "edit" to follow the prompts.

## Restrictions

CustomChat offers flexibility in managing permissions. Should you wish to impose restrictions, such as prohibiting users from executing commands, you can effortlessly adjust settings in the configuration file. By toggling values from True to False, you can define the level of access granted to users.

## Capabilities

CustomChat boasts an array of functionalities to enhance user experience:

- **Website and File Access:** Configure CustomChat to open websites and files as per your requirements.
- **Command Execution:** Enable CustomChat to execute commands, providing seamless interaction.
- **Keyword-based Responses:** Customize CustomChat to deliver specific responses based on designated keywords.

Moreover, CustomChat's capabilities extend to:

- **Web Scraping:** Leveraging web scraping capabilities, CustomChat can retrieve information from various online sources.
- **General Knowledge:** Accessing Google through web scraping, CustomChat can provide answers to general inquiries.
- **Command Line Integration:** With access to the command line, CustomChat enables users to execute commands effortlessly by typing "run" followed by the desired command.

For further information about the AI powering CustomChat, visit [Jimbot AI](https://jb.mrpi314.com/ai).

Enhance your chatbot experience with CustomChat's versatility and adaptability.
